@@ -28,24 +28,26 @@
  * customize them 
  */
 
-#ifndef NTL_PROPERTY_BROWSER_H
-#define NTL_PROPERTY_BROWSER_H
+#ifndef NAUTILUS_PROPERTY_BROWSER_H
+#define NAUTILUS_PROPERTY_BROWSER_H
 
-#include <gtk/gtkwindow.h>
+#include <gdk/gdk.h>
+#include <gtk/gtk.h>
 
 typedef struct NautilusPropertyBrowser NautilusPropertyBrowser;
 typedef struct NautilusPropertyBrowserClass  NautilusPropertyBrowserClass;
 
-#define NAUTILUS_TYPE_PROPERTY_BROWSER \
-	(nautilus_property_browser_get_type ())
+#define NAUTILUS_TYPE_PROPERTY_BROWSER nautilus_property_browser_get_type()
 #define NAUTILUS_PROPERTY_BROWSER(obj) \
-	(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_PROPERTY_BROWSER, NautilusPropertyBrowser))
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_PROPERTY_BROWSER, NautilusPropertyBrowser))
 #define NAUTILUS_PROPERTY_BROWSER_CLASS(klass) \
-	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_PROPERTY_BROWSER, NautilusPropertyBrowserClass))
+  (G_TYPE_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_PROPERTY_BROWSER, NautilusPropertyBrowserClass))
 #define NAUTILUS_IS_PROPERTY_BROWSER(obj) \
-	(GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_PROPERTY_BROWSER))
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NAUTILUS_TYPE_PROPERTY_BROWSER))
 #define NAUTILUS_IS_PROPERTY_BROWSER_CLASS(klass) \
-	(GTK_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_PROPERTY_BROWSER))
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_PROPERTY_BROWSER))
+#define NAUTILUS_PROPERTY_BROWSER_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_PROPERTY_BROWSER, NautilusPropertyBrowserClass))
 
 typedef struct NautilusPropertyBrowserDetails NautilusPropertyBrowserDetails;
 
@@ -60,10 +62,10 @@ struct NautilusPropertyBrowserClass
 	GtkWindowClass parent_class;
 };
 
-GtkType nautilus_property_browser_get_type (void);
-NautilusPropertyBrowser *nautilus_property_browser_new (void);
-void nautilus_property_browser_show (void);
-void nautilus_property_browser_set_path (NautilusPropertyBrowser *panel,
-					 const char         *new_path);
+GType                    nautilus_property_browser_get_type (void);
+NautilusPropertyBrowser *nautilus_property_browser_new      (GdkScreen               *screen);
+void                     nautilus_property_browser_show     (GdkScreen               *screen);
+void                     nautilus_property_browser_set_path (NautilusPropertyBrowser *panel,
+							     const char              *new_path);
 
-#endif /* NTL_PROPERTY_BROWSER_H */
+#endif /* NAUTILUS_PROPERTY_BROWSER_H */
