@@ -118,6 +118,11 @@ should_open_in_new_tab (void)
 	GdkEvent *event;
 
 	event = gtk_get_current_event ();
+
+	if (event == NULL) {
+		return FALSE;
+	}
+
 	if (event->type == GDK_BUTTON_PRESS || event->type == GDK_BUTTON_RELEASE) {
 		return event->button.button == 2;
 	}
@@ -162,8 +167,10 @@ nautilus_menus_append_bookmark_to_menu (NautilusWindow *window,
 	BookmarkHolder *bookmark_holder;
 	char action_name[128];
 	char *name;
+	char *path;
 	GdkPixbuf *pixbuf;
 	GtkAction *action;
+	GtkWidget *menuitem;
 
 	g_assert (NAUTILUS_IS_WINDOW (window));
 	g_assert (NAUTILUS_IS_BOOKMARK (bookmark));
@@ -203,7 +210,14 @@ nautilus_menus_append_bookmark_to_menu (NautilusWindow *window,
 			       GTK_UI_MANAGER_MENUITEM,
 			       FALSE);
 
+	path = g_strdup_printf ("%s/%s", parent_path, action_name);
+	menuitem = gtk_ui_manager_get_widget (window->details->ui_manager,
+					      path);
+	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menuitem),
+						   TRUE);
+
 	g_object_unref (pixbuf);
+	g_free (path);
 	g_free (name);
 }
 
@@ -519,7 +533,7 @@ action_about_nautilus_callback (GtkAction *action,
 			       "comments", _("Nautilus lets you organize "
 					     "files and folders, both on "
 					     "your computer and online."),
-			       "copyright", _("Copyright \xC2\xA9 1999-2008 "
+			       "copyright", _("Copyright \xC2\xA9 1999-2009 "
 					      "The Nautilus authors"),
 			       "license", license_trans,
 			       "wrap-license", TRUE,
@@ -531,7 +545,7 @@ action_about_nautilus_callback (GtkAction *action,
 				 */
 			      "translator-credits", _("translator-credits"),
 			      "logo-icon-name", "nautilus",
-			      "website", "http://www.gnome.org/projects/nautilus",
+			      "website", "http://live.gnome.org/Nautilus",
 			      "website-label", _("Nautilus Web Site"),
 			      NULL);
 
@@ -591,7 +605,7 @@ menu_item_select_cb (GtkMenuItem *proxy,
 	GtkAction *action;
 	char *message;
 
-	action = gtk_widget_get_action (GTK_WIDGET (proxy));
+	action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (proxy));
 	g_return_if_fail (action != NULL);
 	
 	g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
@@ -644,7 +658,7 @@ proxy_button_press_event_cb (GtkButton *button,
 			     gpointer user_data)
 {
 	if (event->button == 2) {
-		gtk_button_pressed (button);
+		g_signal_emit_by_name (button, "pressed", 0);
 	}
 
 	return FALSE;
@@ -656,7 +670,7 @@ proxy_button_release_event_cb (GtkButton *button,
 			       gpointer user_data)
 {
 	if (event->button == 2) {
-		gtk_button_released (button);
+		g_signal_emit_by_name (button, "released", 0);
 	}
 
 	return FALSE;
@@ -979,7 +993,7 @@ add_extension_menu_items (NautilusWindow *window,
 		g_object_get (item, "menu", &menu, NULL);
 		
 		action = nautilus_action_from_menu_item (item);
-		gtk_action_group_add_action (action_group, action);
+		gtk_action_group_add_action_with_accel (action_group, action, NULL);
 		
 		path = g_build_path ("/", POPUP_PATH_EXTENSION_ACTIONS, subdirectory, NULL);
 		gtk_ui_manager_add_ui (ui_manager,
